//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithFuroChance](index.md)/[pass](pass.md)

# pass

[common]\
val [pass](pass.md): [ShantenWithoutGot](../-shanten-without-got/index.md)?

Pass后的向听信息
